==> owncloud_7.0.0~rc1%2Bdfsg.orig.tar.bz2: owncloud/apps/activity/l10n/it.php <==
<?php
$TRANSLATIONS = array(
"Your settings have been updated." => "Le tue impostazioni sono state aggiornate.",
"Activity" => "Attività",
"A file or folder has been <strong>shared</strong>" => "Un file o una cartella è stato <strong>condiviso</strong>",
"A new file or folder has been <strong>created</strong> in a shared folder" => "Un file o una cartella è stato <strong>creato</strong> in una cartella condivisa",
"A file or folder has been <strong>changed</strong> in a shared folder" => "Un file o una cartella è stato <strong>modificato</strong> in una cartella condivisa",
"A file or folder has been <strong>deleted</strong> from a shared folder" => "Un file o una cartella è stato <strong>eliminato</strong> in una cartella condivisa",
"You created %1\$s" => "Hai creato %1\$s",
"%2\$s created %1\$s" => "%2\$s ha creato %1\$s",
"You changed %1\$s" => "Hai modificato %1\$s",
"%2\$s changed %1\$s" => "%2\$s ha modificato %1\$s",
"You deleted %1\$s" => "Hai eliminato %1\$s",
"%2\$s deleted %1\$s" => "%2\$s ha eliminato %1\$s",
"You shared %1\$s with %2\$s" => "Hai condiviso %1\$s con %2\$s",
"You shared %1\$s with group %2\$s" => "Hai condiviso %1\$s con il gruppo %2\$s",
"%2\$s shared %1\$s with you" => "%2\$s ha condiviso %1\$s con te",
"You shared %1\$s via link" => "Hai condiviso %1\$s con collegamento",
"Activity notification" => "Notifica delle attività",
"All Activities" => "Tutte le attività",
"Activities by you" => "Le tue attività",
"Activities by others" => "Attività altrui",
"Shares" => "Condivisioni",
"Files" => "File",
"%s and %s" => "%s e %s",
", " => ", ",
"_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_::_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_" => array("%s e <strong class=\"tooltip\" title=\"%s\">%n altro</strong>","%s e <strong class=\"tooltip\" title=\"%s\">%n altri</strong>"),
"_%s and %n more_::_%s and %n more_" => array("%s e %n altro","%s e %n altri"),
"Hello %s," => "Ciao %s,",
"You are receiving this email because in the last hour the following things happened at %s" => "Hai ricevuto questa email poiché nell'ultima ora si sono verificati i seguenti eventi su %s",
"You are receiving this email because in the last day the following things happened at %s" => "Hai ricevuto questa email poiché nell'ultimo giorno si sono verificati i seguenti eventi su %s",
"You are receiving this email because in the last week the following things happened at %s" => "Hai ricevuto questa email poiché nell'ultima settimana si sono verificati i seguenti eventi su %s",
"* %s" => "* %s",
"You will see a list of events here when you start to use your %s." => "Qui vedrai un elenco di eventi quando inizi a utilizzare %s.",
"No more events to load" => "Non ci sono altri eventi da caricare",
"Enable RSS feed" => "Abilita fonte RSS",
"Notifications" => "Notifiche",
"Mail" => "Posta",
"Stream" => "Flusso",
"You need to set up your email address before you can receive notification emails." => "Devi impostare l'indirizzo del tuo utente prima di poter ricevere le email di notifica.",
"Send emails:" => "Invio email:",
"Hourly" => "Ogni ora",
"Daily" => "Quotidiano",
"Weekly" => "Settimanale",
"Activity feed" => "Fonte delle attività",
"Personal activity feed for %s" => "Fonte delle attività personali per %s"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";

==> owncloud_7.0.1~rc1%2Bdfsg.orig.tar.bz2: owncloud/apps/activity/l10n/it.php <==
<?php
$TRANSLATIONS = array(
"Your settings have been updated." => "Le tue impostazioni sono state aggiornate.",
"Activity" => "Attività",
"A file or folder has been <strong>shared</strong>" => "Un file o una cartella è stato <strong>condiviso</strong>",
"A new file or folder has been <strong>created</strong>" => "Un nuovo file o cartella è stato <strong>creato</strong>",
"A file or folder has been <strong>changed</strong>" => "Un file o una cartella è stato <strong>modificato</strong>",
"A file or folder has been <strong>deleted</strong>" => "Un file o una cartella è stato <strong>eliminato</strong>",
"You created %1\$s" => "Hai creato %1\$s",
"%2\$s created %1\$s" => "%2\$s ha creato %1\$s",
"You changed %1\$s" => "Hai modificato %1\$s",
"%2\$s changed %1\$s" => "%2\$s ha modificato %1\$s",
"You deleted %1\$s" => "Hai eliminato %1\$s",
"%2\$s deleted %1\$s" => "%2\$s ha eliminato %1\$s",
"You shared %1\$s with %2\$s" => "Hai condiviso %1\$s con %2\$s",
"You shared %1\$s with group %2\$s" => "Hai condiviso %1\$s con il gruppo %2\$s",
"%2\$s shared %1\$s with you" => "%2\$s ha condiviso %1\$s con te",
"You shared %1\$s via link" => "Hai condiviso %1\$s tramite collegamento",
"Activity notification" => "Notifica delle attività",
"All Activities" => "Tutte le attività",
"Activities by you" => "Le tue attività",
"Activities by others" => "Attività altrui",
"Shares" => "Condivisioni",
"Files" => "File",
"%s and %s" => "%s e %s",
", " => ", ",
"_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_::_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_" => array("%s e <strong class=\"tooltip\" title=\"%s\">%n altro</strong>","%s e <strong class=\"tooltip\" title=\"%s\">%n altri</strong>"),
"_%s and %n more_::_%s and %n more_" => array("%s e %n altro","%s e %n altri"),
"Hello %s," => "Ciao %s,",
"You are receiving this email because in the last hour the following things happened at %s" => "Hai ricevuto questa email poiché nell'ultima ora si sono verificati i seguenti eventi su %s",
"You are receiving this email because in the last day the following things happened at %s" => "Hai ricevuto questa email poiché nell'ultimo giorno si sono verificati i seguenti eventi su %s",
"You are receiving this email because in the last week the following things happened at %s" => "Hai ricevuto questa email poiché nell'ultima settimana si sono verificati i seguenti eventi su %s",
"* %s" => "* %s",
"You will see a list of events here when you start to use your %s." => "Qui vedrai un elenco di eventi quando inizi a utilizzare %s.",
"No more events to load" => "Non ci sono altri eventi da caricare",
"Enable RSS feed" => "Abilita fonte RSS",
"Notifications" => "Notifiche",
"Mail" => "Posta",
"Stream" => "Flusso",
"Notify about my own actions" => "Notificami le mie azioni",
"You need to set up your email address before you can receive notification emails." => "Devi impostare l'indirizzo del tuo utente prima di poter ricevere le email di notifica.",
"Send emails:" => "Invio email:",
"Hourly" => "Ogni ora",
"Daily" => "Quotidiano",
"Weekly" => "Settimanale",
"Activity feed" => "Fonte delle attività",
"Personal activity feed for %s" => "Fonte delle attività personali per %s"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
